==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudwatch/kotlin/inputs/GetLogGroupPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudwatch.kotlin.inputs

import com.pulumi.aws.cloudwatch.inputs.GetLogGroupPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getLogGroup.
 * @property name Name of the Cloudwatch log group
 * @property tags Map of tags to assign to the resource.
 */
public data class GetLogGroupPlainArgs(
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.cloudwatch.inputs.GetLogGroupPlainArgs> {
    override fun toJava(): com.pulumi.aws.cloudwatch.inputs.GetLogGroupPlainArgs =
        com.pulumi.aws.cloudwatch.inputs.GetLogGroupPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetLogGroupPlainArgs].
 */
@PulumiTagMarker
public class GetLogGroupPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the Cloudwatch log group
     */
    @JvmName("vxitohpmuueqwtms")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags to assign to the resource.
     */
    @JvmName("imrmewvfqkdlqaey")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags to assign to the resource.
     */
    @JvmName("sqnlpslxhuyfeovi")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetLogGroupPlainArgs = GetLogGroupPlainArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudwatch/kotlin/inputs/GetLogGroupPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudwatch.kotlin.inputs

import com.pulumi.aws.cloudwatch.inputs.GetLogGroupPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getLogGroup.
 * @property name Name of the Cloudwatch log group
 * @property tags Map of tags to assign to the resource.
 */
public data class GetLogGroupPlainArgs(
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.cloudwatch.inputs.GetLogGroupPlainArgs> {
    override fun toJava(): com.pulumi.aws.cloudwatch.inputs.GetLogGroupPlainArgs =
        com.pulumi.aws.cloudwatch.inputs.GetLogGroupPlainArgs.builder()
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetLogGroupPlainArgs].
 */
@PulumiTagMarker
public class GetLogGroupPlainArgsBuilder internal constructor() {
    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the Cloudwatch log group
     */
    @JvmName("dfohmfvypechroyx")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags to assign to the resource.
     */
    @JvmName("voqvtwekjylkayhs")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags to assign to the resource.
     */
    @JvmName("rcxdrjuvwbxuudwg")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetLogGroupPlainArgs = GetLogGroupPlainArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}
